@@ -40,12 +40,6 @@ def check_type(typ, arg, name=''):
                               % (typ_string, name, arg, type(arg).__name__))
 
 
-@check_function
-def check_strategy(arg, name=''):
-    from hypothesis.searchstrategy import SearchStrategy
-    check_type(SearchStrategy, arg, name)
-
-
 @check_function
 def check_valid_integer(value):
     """Checks that value is either unspecified, or a valid integer.
@@ -71,6 +65,18 @@ def check_valid_bound(value, name):
         raise InvalidArgument(u'Invalid end point %s=%r' % (name, value))
 
 
+@check_function
+def check_valid_magnitude(value, name):
+    """Checks that value is either unspecified, or a non-negative valid
+    interval bound.
+
+    Otherwise raises InvalidArgument.
+    """
+    check_valid_bound(value, name)
+    if value is not None and value < 0:
+        raise InvalidArgument('%s=%r must not be negative.' % (name, value))
+
+
 @check_function
 def try_convert(typ, value, name):
     if value is None:
